/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FolderPath } from "./FolderPath";
import type { IncludeFiles } from "./IncludeFiles";
import type { IncludeVirtualFolders } from "./IncludeVirtualFolders";
import type { IterateFolderRecursively } from "./IterateFolderRecursively";

/**
 * Request body for DeleteFolder.
 *
 * Please note:
 *
 * - If the folder has overridden storage settings, then no files will be deleted.
 *
 * - If the folder has inherited storage settings, then its files will be deleted if `deleteFiles` is `true`.
 *
 * - If the folder contains sub-folders that have overridden storage settings, then their files will not be deleted, regardless of `deleteFiles`.
 *
 * You can use ListFolder to preview the operation: set `dryRun=true` with ```recursive```, ```includeFiles``` and ```includeVirtualFolders``` set to match the values you're using here. Leave all other flags unset.
 */
export type DeleteFolderRequest = {
  /**
   * If `true` then deletes files.
   *
   * Default: true
   */
  deleteFiles?: IncludeFiles;
  /**
   * If `true` then deletes all virtual folder settings at the current path and below.
   *
   * Virtual folders are folders that have been created using the PutFolder operation.
   *
   * Default: true
   */
  deleteVirtualFolders?: IncludeVirtualFolders;
  /**
   * The folder to delete.
   */
  folderPath: FolderPath;
  /**
   * If `true` then deletes files and virtual folders that are descendants of `folderPath`.
   *
   * If `false` then only deletes files that are direct children of `folderPath`, and does not delete descendant virtual folders (children or otherwise).
   *
   * Default: true
   */
  recursive?: IterateFolderRecursively;
};
